Class: BillingApi::PricingPlan

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_billing_api/models/pricing_plan.rb

Overview

Pricing plan details.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PricingPlan

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `BillingApi::PricingPlan` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `BillingApi::PricingPlan`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'sku')
    self.sku = attributes[:'sku']
  else
    self.sku = nil
  end

  if attributes.key?(:'sku_description')
    self.sku_description = attributes[:'sku_description']
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  else
    self.location = nil
  end

  if attributes.key?(:'pricing_model')
    self.pricing_model = attributes[:'pricing_model']
  else
    self.pricing_model = nil
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  else
    self.price = nil
  end

  if attributes.key?(:'price_unit')
    self.price_unit = attributes[:'price_unit']
  else
    self.price_unit = nil
  end

  if attributes.key?(:'applicable_discounts')
    self.applicable_discounts = attributes[:'applicable_discounts']
  end

  if attributes.key?(:'correlated_product_code')
    self.correlated_product_code = attributes[:'correlated_product_code']
  end

  if attributes.key?(:'package_quantity')
    self.package_quantity = attributes[:'package_quantity']
  end

  if attributes.key?(:'package_unit')
    self.package_unit = attributes[:'package_unit']
  end

  if attributes.key?(:'package_details')
    self.package_details = attributes[:'package_details']
  end
end

Instance Attribute Details

#applicable_discountsObject

Returns the value of attribute applicable_discounts.



36
37
38
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 36

def applicable_discounts
  @applicable_discounts
end

#correlated_product_codeObject

Product code of the product this product is correlated with



39
40
41
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 39

def correlated_product_code
  @correlated_product_code
end

#locationObject

The code identifying the location.



26
27
28
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 26

def location
  @location
end

#package_detailsObject

Returns the value of attribute package_details.



46
47
48
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 46

def package_details
  @package_details
end

#package_quantityObject

Package size per month.



42
43
44
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 42

def package_quantity
  @package_quantity
end

#package_unitObject

Returns the value of attribute package_unit.



44
45
46
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 44

def package_unit
  @package_unit
end

#priceObject

The price per unit.



32
33
34
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 32

def price
  @price
end

#price_unitObject

Returns the value of attribute price_unit.



34
35
36
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 34

def price_unit
  @price_unit
end

#pricing_modelObject

The pricing model.



29
30
31
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 29

def pricing_model
  @pricing_model
end

#skuObject

The SKU identifying this pricing plan.



20
21
22
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 20

def sku
  @sku
end

#sku_descriptionObject

Description of this pricing plan.



23
24
25
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 23

def sku_description
  @sku_description
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



88
89
90
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 88

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



93
94
95
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 93

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 71

def self.attribute_map
  {
    :'sku' => :'sku',
    :'sku_description' => :'skuDescription',
    :'location' => :'location',
    :'pricing_model' => :'pricingModel',
    :'price' => :'price',
    :'price_unit' => :'priceUnit',
    :'applicable_discounts' => :'applicableDiscounts',
    :'correlated_product_code' => :'correlatedProductCode',
    :'package_quantity' => :'packageQuantity',
    :'package_unit' => :'packageUnit',
    :'package_details' => :'packageDetails'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 318

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 115

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 98

def self.openapi_types
  {
    :'sku' => :'String',
    :'sku_description' => :'String',
    :'location' => :'String',
    :'pricing_model' => :'String',
    :'price' => :'Float',
    :'price_unit' => :'PriceUnitEnum',
    :'applicable_discounts' => :'ApplicableDiscounts',
    :'correlated_product_code' => :'String',
    :'package_quantity' => :'Float',
    :'package_unit' => :'PackageUnitEnum',
    :'package_details' => :'PackageDetails'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 287

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      sku == o.sku &&
      sku_description == o.sku_description &&
      location == o.location &&
      pricing_model == o.pricing_model &&
      price == o.price &&
      price_unit == o.price_unit &&
      applicable_discounts == o.applicable_discounts &&
      correlated_product_code == o.correlated_product_code &&
      package_quantity == o.package_quantity &&
      package_unit == o.package_unit &&
      package_details == o.package_details
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


305
306
307
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 305

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



311
312
313
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 311

def hash
  [sku, sku_description, location, pricing_model, price, price_unit, applicable_discounts, correlated_product_code, package_quantity, package_unit, package_details].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 193

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @sku.nil?
    invalid_properties.push('invalid value for "sku", sku cannot be nil.')
  end

  if @location.nil?
    invalid_properties.push('invalid value for "location", location cannot be nil.')
  end

  if @pricing_model.nil?
    invalid_properties.push('invalid value for "pricing_model", pricing_model cannot be nil.')
  end

  if @price.nil?
    invalid_properties.push('invalid value for "price", price cannot be nil.')
  end

  if @price_unit.nil?
    invalid_properties.push('invalid value for "price_unit", price_unit cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 340

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/pnap_billing_api/models/pricing_plan.rb', line 221

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @sku.nil?
  return false if @location.nil?
  location_validator = EnumAttributeValidator.new('String', ["PHX", "ASH", "NLD", "SGP", "CHI", "SEA", "GLOBAL"])
  return false unless location_validator.valid?(@location)
  return false if @pricing_model.nil?
  pricing_model_validator = EnumAttributeValidator.new('String', ["HOURLY", "METERED", "ONE_MONTH_RESERVATION", "TWELVE_MONTHS_RESERVATION", "TWENTY_FOUR_MONTHS_RESERVATION", "THIRTY_SIX_MONTHS_RESERVATION", "MONTHLY_PACKAGE", "FREE_TIER"])
  return false unless pricing_model_validator.valid?(@pricing_model)
  return false if @price.nil?
  return false if @price_unit.nil?
  true
end