Class: BillingApi::ProductAvailabilityApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pnap_billing_api/api/product_availability_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ProductAvailabilityApi

Returns a new instance of ProductAvailabilityApi.



19
20
21
# File 'lib/pnap_billing_api/api/product_availability_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pnap_billing_api/api/product_availability_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#product_availability_get(opts = {}) ⇒ Array<ProductAvailability>

List all Product availabilities. Retrieves the list of product availability details.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :product_category (Array<String>)

    Product category. Currently only SERVER category is supported.

  • :product_code (Array<String>)
  • :show_only_min_quantity_available (Boolean)

    Show only locations where product with requested quantity is available or all locations where product is offered. (default to true)

  • :location (Array<ProductLocationEnum>)
  • :solution (Array<String>)
  • :min_quantity (Float)

    Minimum quantity of the product that can be requested. For servers the allowed quantity range is 1 to 10.

Returns:



32
33
34
35
# File 'lib/pnap_billing_api/api/product_availability_api.rb', line 32

def product_availability_get(opts = {})
  data, _status_code, _headers = product_availability_get_with_http_info(opts)
  data
end

#product_availability_get_with_http_info(opts = {}) ⇒ Array<(Array<ProductAvailability>, Integer, Hash)>

List all Product availabilities. Retrieves the list of product availability details.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :product_category (Array<String>)

    Product category. Currently only SERVER category is supported.

  • :product_code (Array<String>)
  • :show_only_min_quantity_available (Boolean)

    Show only locations where product with requested quantity is available or all locations where product is offered. (default to true)

  • :location (Array<ProductLocationEnum>)
  • :solution (Array<String>)
  • :min_quantity (Float)

    Minimum quantity of the product that can be requested. For servers the allowed quantity range is 1 to 10.

Returns:

  • (Array<(Array<ProductAvailability>, Integer, Hash)>)

    Array<ProductAvailability> data, response status code and response headers



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/pnap_billing_api/api/product_availability_api.rb', line 47

def product_availability_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProductAvailabilityApi.product_availability_get ...'
  end
  allowable_values = ["SERVER"]
  if @api_client.config.client_side_validation && opts[:'product_category'] && !opts[:'product_category'].all? { |item| allowable_values.include?(item) }
    fail ArgumentError, "invalid value for \"product_category\", must include one of #{allowable_values}"
  end
  allowable_values = ["SERVER_RANCHER"]
  if @api_client.config.client_side_validation && opts[:'solution'] && !opts[:'solution'].all? { |item| allowable_values.include?(item) }
    fail ArgumentError, "invalid value for \"solution\", must include one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'min_quantity'].nil? && opts[:'min_quantity'] > 10
    fail ArgumentError, 'invalid value for "opts[:"min_quantity"]" when calling ProductAvailabilityApi.product_availability_get, must be smaller than or equal to 10.'
  end

  if @api_client.config.client_side_validation && !opts[:'min_quantity'].nil? && opts[:'min_quantity'] < 1
    fail ArgumentError, 'invalid value for "opts[:"min_quantity"]" when calling ProductAvailabilityApi.product_availability_get, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/product-availability'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'productCategory'] = @api_client.build_collection_param(opts[:'product_category'], :multi) if !opts[:'product_category'].nil?
  query_params[:'productCode'] = @api_client.build_collection_param(opts[:'product_code'], :multi) if !opts[:'product_code'].nil?
  query_params[:'showOnlyMinQuantityAvailable'] = opts[:'show_only_min_quantity_available'] if !opts[:'show_only_min_quantity_available'].nil?
  query_params[:'location'] = @api_client.build_collection_param(opts[:'location'], :multi) if !opts[:'location'].nil?
  query_params[:'solution'] = @api_client.build_collection_param(opts[:'solution'], :multi) if !opts[:'solution'].nil?
  query_params[:'minQuantity'] = opts[:'min_quantity'] if !opts[:'min_quantity'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<ProductAvailability>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"ProductAvailabilityApi.product_availability_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProductAvailabilityApi#product_availability_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end