Class: BillingApi::PromoCreditDetails

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_billing_api/models/promo_credit_details.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PromoCreditDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `BillingApi::PromoCreditDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `BillingApi::PromoCreditDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'applied_amount')
    self.applied_amount = attributes[:'applied_amount']
  else
    self.applied_amount = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'coupon_id')
    self.coupon_id = attributes[:'coupon_id']
  else
    self.coupon_id = nil
  end

  if attributes.key?(:'coupon_code')
    self.coupon_code = attributes[:'coupon_code']
  else
    self.coupon_code = nil
  end
end

Instance Attribute Details

#applied_amountObject

Amount applied.



19
20
21
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 19

def applied_amount
  @applied_amount
end

#coupon_codeObject

Coupon code which is the source of the promo credit.



27
28
29
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 27

def coupon_code
  @coupon_code
end

#coupon_idObject

Coupon id which is the source of the promo credit.



24
25
26
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 24

def coupon_id
  @coupon_id
end

#typeObject

Returns the value of attribute type.



21
22
23
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 21

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 52

def self.attribute_map
  {
    :'applied_amount' => :'appliedAmount',
    :'type' => :'type',
    :'coupon_id' => :'couponId',
    :'coupon_code' => :'couponCode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 236

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



88
89
90
91
92
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 88

def self.openapi_all_of
  [
  :'CreditDetailsBase'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 72

def self.openapi_types
  {
    :'applied_amount' => :'Float',
    :'type' => :'CreditTypeEnum',
    :'coupon_id' => :'String',
    :'coupon_code' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



212
213
214
215
216
217
218
219
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 212

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      applied_amount == o.applied_amount &&
      type == o.type &&
      coupon_id == o.coupon_id &&
      coupon_code == o.coupon_code
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 223

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



229
230
231
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 229

def hash
  [applied_amount, type, coupon_id, coupon_code].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 137

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @applied_amount.nil?
    invalid_properties.push('invalid value for "applied_amount", applied_amount cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @coupon_id.nil?
    invalid_properties.push('invalid value for "coupon_id", coupon_id cannot be nil.')
  end

  if @coupon_code.nil?
    invalid_properties.push('invalid value for "coupon_code", coupon_code cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 258

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



161
162
163
164
165
166
167
168
# File 'lib/pnap_billing_api/models/promo_credit_details.rb', line 161

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @applied_amount.nil?
  return false if @type.nil?
  return false if @coupon_id.nil?
  return false if @coupon_code.nil?
  true
end