Class: BillingApi::Reservation

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_billing_api/models/reservation.rb

Overview

Reservation details

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Reservation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/pnap_billing_api/models/reservation.rb', line 162

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `BillingApi::Reservation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `BillingApi::Reservation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'product_code')
    self.product_code = attributes[:'product_code']
  else
    self.product_code = nil
  end

  if attributes.key?(:'product_category')
    self.product_category = attributes[:'product_category']
  else
    self.product_category = nil
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  else
    self.location = nil
  end

  if attributes.key?(:'reservation_model')
    self.reservation_model = attributes[:'reservation_model']
  else
    self.reservation_model = nil
  end

  if attributes.key?(:'term')
    self.term = attributes[:'term']
  end

  if attributes.key?(:'reservation_state')
    self.reservation_state = attributes[:'reservation_state']
  else
    self.reservation_state = nil
  end

  if attributes.key?(:'initial_invoice_model')
    self.initial_invoice_model = attributes[:'initial_invoice_model']
  end

  if attributes.key?(:'quantity')
    self.quantity = attributes[:'quantity']
  else
    self.quantity = nil
  end

  if attributes.key?(:'start_date_time')
    self.start_date_time = attributes[:'start_date_time']
  else
    self.start_date_time = nil
  end

  if attributes.key?(:'end_date_time')
    self.end_date_time = attributes[:'end_date_time']
  end

  if attributes.key?(:'last_renewal_date_time')
    self.last_renewal_date_time = attributes[:'last_renewal_date_time']
  end

  if attributes.key?(:'next_renewal_date_time')
    self.next_renewal_date_time = attributes[:'next_renewal_date_time']
  end

  if attributes.key?(:'auto_renew')
    self.auto_renew = attributes[:'auto_renew']
  else
    self.auto_renew = nil
  end

  if attributes.key?(:'sku')
    self.sku = attributes[:'sku']
  else
    self.sku = nil
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  else
    self.price = nil
  end

  if attributes.key?(:'price_unit')
    self.price_unit = attributes[:'price_unit']
  else
    self.price_unit = nil
  end

  if attributes.key?(:'assigned_resource_id')
    self.assigned_resource_id = attributes[:'assigned_resource_id']
  end

  if attributes.key?(:'next_billing_date')
    self.next_billing_date = attributes[:'next_billing_date']
  end

  if attributes.key?(:'utilization')
    self.utilization = attributes[:'utilization']
  end
end

Instance Attribute Details

#assigned_resource_idObject

The resource ID currently being assigned to Reservation.



63
64
65
# File 'lib/pnap_billing_api/models/reservation.rb', line 63

def assigned_resource_id
  @assigned_resource_id
end

#auto_renewObject

A flag indicating whether the reservation will auto-renew (default is true).



52
53
54
# File 'lib/pnap_billing_api/models/reservation.rb', line 52

def auto_renew
  @auto_renew
end

#end_date_timeObject

The point in time (in UTC) when the reservation end.



43
44
45
# File 'lib/pnap_billing_api/models/reservation.rb', line 43

def end_date_time
  @end_date_time
end

#idObject

The reservation identifier.



20
21
22
# File 'lib/pnap_billing_api/models/reservation.rb', line 20

def id
  @id
end

#initial_invoice_modelObject

Returns the value of attribute initial_invoice_model.



35
36
37
# File 'lib/pnap_billing_api/models/reservation.rb', line 35

def initial_invoice_model
  @initial_invoice_model
end

#last_renewal_date_timeObject

The point in time (in UTC) when the reservation was renewed last.



46
47
48
# File 'lib/pnap_billing_api/models/reservation.rb', line 46

def last_renewal_date_time
  @last_renewal_date_time
end

#locationObject

Returns the value of attribute location.



27
28
29
# File 'lib/pnap_billing_api/models/reservation.rb', line 27

def location
  @location
end

#next_billing_dateObject

Next billing date for Reservation.



66
67
68
# File 'lib/pnap_billing_api/models/reservation.rb', line 66

def next_billing_date
  @next_billing_date
end

#next_renewal_date_timeObject

The point in time (in UTC) when the reservation will be renewed if auto renew is set to true.



49
50
51
# File 'lib/pnap_billing_api/models/reservation.rb', line 49

def next_renewal_date_time
  @next_renewal_date_time
end

#priceObject

Reservation price.



58
59
60
# File 'lib/pnap_billing_api/models/reservation.rb', line 58

def price
  @price
end

#price_unitObject

Returns the value of attribute price_unit.



60
61
62
# File 'lib/pnap_billing_api/models/reservation.rb', line 60

def price_unit
  @price_unit
end

#product_categoryObject

Returns the value of attribute product_category.



25
26
27
# File 'lib/pnap_billing_api/models/reservation.rb', line 25

def product_category
  @product_category
end

#product_codeObject

The code identifying the product. The same code is used for this product across all locations.



23
24
25
# File 'lib/pnap_billing_api/models/reservation.rb', line 23

def product_code
  @product_code
end

#quantityObject

Returns the value of attribute quantity.



37
38
39
# File 'lib/pnap_billing_api/models/reservation.rb', line 37

def quantity
  @quantity
end

#reservation_modelObject

Returns the value of attribute reservation_model.



29
30
31
# File 'lib/pnap_billing_api/models/reservation.rb', line 29

def reservation_model
  @reservation_model
end

#reservation_stateObject

Returns the value of attribute reservation_state.



33
34
35
# File 'lib/pnap_billing_api/models/reservation.rb', line 33

def reservation_state
  @reservation_state
end

#skuObject

The sku that will be applied to this reservation. It is useful to find out the price by querying the /product endpoint.



55
56
57
# File 'lib/pnap_billing_api/models/reservation.rb', line 55

def sku
  @sku
end

#start_date_timeObject

The point in time (in UTC) when the reservation starts.



40
41
42
# File 'lib/pnap_billing_api/models/reservation.rb', line 40

def start_date_time
  @start_date_time
end

#termObject

Returns the value of attribute term.



31
32
33
# File 'lib/pnap_billing_api/models/reservation.rb', line 31

def term
  @term
end

#utilizationObject

Returns the value of attribute utilization.



68
69
70
# File 'lib/pnap_billing_api/models/reservation.rb', line 68

def utilization
  @utilization
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



119
120
121
# File 'lib/pnap_billing_api/models/reservation.rb', line 119

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



124
125
126
# File 'lib/pnap_billing_api/models/reservation.rb', line 124

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/pnap_billing_api/models/reservation.rb', line 93

def self.attribute_map
  {
    :'id' => :'id',
    :'product_code' => :'productCode',
    :'product_category' => :'productCategory',
    :'location' => :'location',
    :'reservation_model' => :'reservationModel',
    :'term' => :'term',
    :'reservation_state' => :'reservationState',
    :'initial_invoice_model' => :'initialInvoiceModel',
    :'quantity' => :'quantity',
    :'start_date_time' => :'startDateTime',
    :'end_date_time' => :'endDateTime',
    :'last_renewal_date_time' => :'lastRenewalDateTime',
    :'next_renewal_date_time' => :'nextRenewalDateTime',
    :'auto_renew' => :'autoRenew',
    :'sku' => :'sku',
    :'price' => :'price',
    :'price_unit' => :'priceUnit',
    :'assigned_resource_id' => :'assignedResourceId',
    :'next_billing_date' => :'nextBillingDate',
    :'utilization' => :'utilization'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
# File 'lib/pnap_billing_api/models/reservation.rb', line 518

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



155
156
157
158
# File 'lib/pnap_billing_api/models/reservation.rb', line 155

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/pnap_billing_api/models/reservation.rb', line 129

def self.openapi_types
  {
    :'id' => :'String',
    :'product_code' => :'String',
    :'product_category' => :'ReservationProductCategoryEnum',
    :'location' => :'LocationEnum',
    :'reservation_model' => :'ReservationModelEnum',
    :'term' => :'ReservationTerm',
    :'reservation_state' => :'ReservationStateEnum',
    :'initial_invoice_model' => :'ReservationInvoicingModelEnum',
    :'quantity' => :'Quantity',
    :'start_date_time' => :'Time',
    :'end_date_time' => :'Time',
    :'last_renewal_date_time' => :'Time',
    :'next_renewal_date_time' => :'Time',
    :'auto_renew' => :'Boolean',
    :'sku' => :'String',
    :'price' => :'Float',
    :'price_unit' => :'PriceUnitEnum',
    :'assigned_resource_id' => :'String',
    :'next_billing_date' => :'Date',
    :'utilization' => :'Utilization'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/pnap_billing_api/models/reservation.rb', line 478

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      product_code == o.product_code &&
      product_category == o.product_category &&
      location == o.location &&
      reservation_model == o.reservation_model &&
      term == o.term &&
      reservation_state == o.reservation_state &&
      initial_invoice_model == o.initial_invoice_model &&
      quantity == o.quantity &&
      start_date_time == o.start_date_time &&
      end_date_time == o.end_date_time &&
      last_renewal_date_time == o.last_renewal_date_time &&
      next_renewal_date_time == o.next_renewal_date_time &&
      auto_renew == o.auto_renew &&
      sku == o.sku &&
      price == o.price &&
      price_unit == o.price_unit &&
      assigned_resource_id == o.assigned_resource_id &&
      next_billing_date == o.next_billing_date &&
      utilization == o.utilization
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


505
506
507
# File 'lib/pnap_billing_api/models/reservation.rb', line 505

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



511
512
513
# File 'lib/pnap_billing_api/models/reservation.rb', line 511

def hash
  [id, product_code, product_category, location, reservation_model, term, reservation_state, initial_invoice_model, quantity, start_date_time, end_date_time, last_renewal_date_time, next_renewal_date_time, auto_renew, sku, price, price_unit, assigned_resource_id, next_billing_date, utilization].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/pnap_billing_api/models/reservation.rb', line 283

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @product_code.nil?
    invalid_properties.push('invalid value for "product_code", product_code cannot be nil.')
  end

  if @product_category.nil?
    invalid_properties.push('invalid value for "product_category", product_category cannot be nil.')
  end

  if @location.nil?
    invalid_properties.push('invalid value for "location", location cannot be nil.')
  end

  if @reservation_model.nil?
    invalid_properties.push('invalid value for "reservation_model", reservation_model cannot be nil.')
  end

  if @reservation_state.nil?
    invalid_properties.push('invalid value for "reservation_state", reservation_state cannot be nil.')
  end

  if @quantity.nil?
    invalid_properties.push('invalid value for "quantity", quantity cannot be nil.')
  end

  if @start_date_time.nil?
    invalid_properties.push('invalid value for "start_date_time", start_date_time cannot be nil.')
  end

  if @auto_renew.nil?
    invalid_properties.push('invalid value for "auto_renew", auto_renew cannot be nil.')
  end

  if @sku.nil?
    invalid_properties.push('invalid value for "sku", sku cannot be nil.')
  end

  if @price.nil?
    invalid_properties.push('invalid value for "price", price cannot be nil.')
  end

  if @price_unit.nil?
    invalid_properties.push('invalid value for "price_unit", price_unit cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



540
541
542
543
544
545
546
547
548
549
550
551
552
# File 'lib/pnap_billing_api/models/reservation.rb', line 540

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/pnap_billing_api/models/reservation.rb', line 339

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @product_code.nil?
  return false if @product_category.nil?
  return false if @location.nil?
  return false if @reservation_model.nil?
  return false if @reservation_state.nil?
  return false if @quantity.nil?
  return false if @start_date_time.nil?
  return false if @auto_renew.nil?
  return false if @sku.nil?
  return false if @price.nil?
  return false if @price_unit.nil?
  true
end