Class: BillingApi::ServerProductMetadata

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_billing_api/models/server_product_metadata.rb

Overview

Details of the server product.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ServerProductMetadata

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `BillingApi::ServerProductMetadata` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `BillingApi::ServerProductMetadata`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ram_in_gb')
    self.ram_in_gb = attributes[:'ram_in_gb']
  else
    self.ram_in_gb = nil
  end

  if attributes.key?(:'cpu')
    self.cpu = attributes[:'cpu']
  else
    self.cpu = nil
  end

  if attributes.key?(:'cpu_count')
    self.cpu_count = attributes[:'cpu_count']
  else
    self.cpu_count = nil
  end

  if attributes.key?(:'cores_per_cpu')
    self.cores_per_cpu = attributes[:'cores_per_cpu']
  else
    self.cores_per_cpu = nil
  end

  if attributes.key?(:'cpu_frequency')
    self.cpu_frequency = attributes[:'cpu_frequency']
  else
    self.cpu_frequency = nil
  end

  if attributes.key?(:'network')
    self.network = attributes[:'network']
  else
    self.network = nil
  end

  if attributes.key?(:'storage')
    self.storage = attributes[:'storage']
  else
    self.storage = nil
  end

  if attributes.key?(:'gpu_configurations')
    if (value = attributes[:'gpu_configurations']).is_a?(Array)
      self.gpu_configurations = value
    end
  end
end

Instance Attribute Details

#cores_per_cpuObject

The number of physical cores present on each CPU.



29
30
31
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 29

def cores_per_cpu
  @cores_per_cpu
end

#cpuObject

CPU name.



23
24
25
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 23

def cpu
  @cpu
end

#cpu_countObject

Number of CPUs.



26
27
28
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 26

def cpu_count
  @cpu_count
end

#cpu_frequencyObject

CPU frequency in GHz.



32
33
34
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 32

def cpu_frequency
  @cpu_frequency
end

#gpu_configurationsObject

GPU configurations



41
42
43
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 41

def gpu_configurations
  @gpu_configurations
end

#networkObject

Server network.



35
36
37
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 35

def network
  @network
end

#ram_in_gbObject

RAM in GB.



20
21
22
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 20

def ram_in_gb
  @ram_in_gb
end

#storageObject

Server storage.



38
39
40
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 38

def storage
  @storage
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 44

def self.attribute_map
  {
    :'ram_in_gb' => :'ramInGb',
    :'cpu' => :'cpu',
    :'cpu_count' => :'cpuCount',
    :'cores_per_cpu' => :'coresPerCpu',
    :'cpu_frequency' => :'cpuFrequency',
    :'network' => :'network',
    :'storage' => :'storage',
    :'gpu_configurations' => :'gpuConfigurations'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 302

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 68

def self.openapi_types
  {
    :'ram_in_gb' => :'Float',
    :'cpu' => :'String',
    :'cpu_count' => :'Float',
    :'cores_per_cpu' => :'Float',
    :'cpu_frequency' => :'Float',
    :'network' => :'String',
    :'storage' => :'String',
    :'gpu_configurations' => :'Array<GpuConfigurationMetadata>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 274

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ram_in_gb == o.ram_in_gb &&
      cpu == o.cpu &&
      cpu_count == o.cpu_count &&
      cores_per_cpu == o.cores_per_cpu &&
      cpu_frequency == o.cpu_frequency &&
      network == o.network &&
      storage == o.storage &&
      gpu_configurations == o.gpu_configurations
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


289
290
291
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 289

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



295
296
297
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 295

def hash
  [ram_in_gb, cpu, cpu_count, cores_per_cpu, cpu_frequency, network, storage, gpu_configurations].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 154

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ram_in_gb.nil?
    invalid_properties.push('invalid value for "ram_in_gb", ram_in_gb cannot be nil.')
  end

  if @cpu.nil?
    invalid_properties.push('invalid value for "cpu", cpu cannot be nil.')
  end

  if @cpu_count.nil?
    invalid_properties.push('invalid value for "cpu_count", cpu_count cannot be nil.')
  end

  if @cores_per_cpu.nil?
    invalid_properties.push('invalid value for "cores_per_cpu", cores_per_cpu cannot be nil.')
  end

  if @cpu_frequency.nil?
    invalid_properties.push('invalid value for "cpu_frequency", cpu_frequency cannot be nil.')
  end

  if @network.nil?
    invalid_properties.push('invalid value for "network", network cannot be nil.')
  end

  if @storage.nil?
    invalid_properties.push('invalid value for "storage", storage cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 324

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
195
196
197
198
199
200
# File 'lib/pnap_billing_api/models/server_product_metadata.rb', line 190

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @ram_in_gb.nil?
  return false if @cpu.nil?
  return false if @cpu_count.nil?
  return false if @cores_per_cpu.nil?
  return false if @cpu_frequency.nil?
  return false if @network.nil?
  return false if @storage.nil?
  true
end