Class: BillingApi::StorageDetails
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- BillingApi::StorageDetails
- Defined in:
- lib/pnap_billing_api/models/storage_details.rb
Overview
Details of the storage associated with this rated usage record.
Instance Attribute Summary collapse
-
#capacity_in_gb ⇒ Object
Capacity in GB.
-
#created_on ⇒ Object
Timestamp when the record was created.
-
#network_storage_id ⇒ Object
Network storage ID.
-
#network_storage_name ⇒ Object
Network storage name.
-
#volume_id ⇒ Object
Volume ID.
-
#volume_name ⇒ Object
Volume name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ StorageDetails
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `BillingApi::StorageDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `BillingApi::StorageDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'network_storage_id') self.network_storage_id = attributes[:'network_storage_id'] end if attributes.key?(:'network_storage_name') self.network_storage_name = attributes[:'network_storage_name'] end if attributes.key?(:'volume_id') self.volume_id = attributes[:'volume_id'] end if attributes.key?(:'volume_name') self.volume_name = attributes[:'volume_name'] end if attributes.key?(:'capacity_in_gb') self.capacity_in_gb = attributes[:'capacity_in_gb'] else self.capacity_in_gb = nil end if attributes.key?(:'created_on') self.created_on = attributes[:'created_on'] end end |
Instance Attribute Details
#capacity_in_gb ⇒ Object
Capacity in GB.
32 33 34 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 32 def capacity_in_gb @capacity_in_gb end |
#created_on ⇒ Object
Timestamp when the record was created.
35 36 37 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 35 def created_on @created_on end |
#network_storage_id ⇒ Object
Network storage ID.
20 21 22 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 20 def network_storage_id @network_storage_id end |
#network_storage_name ⇒ Object
Network storage name.
23 24 25 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 23 def network_storage_name @network_storage_name end |
#volume_id ⇒ Object
Volume ID.
26 27 28 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 26 def volume_id @volume_id end |
#volume_name ⇒ Object
Volume name.
29 30 31 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 29 def volume_name @volume_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 38 def self.attribute_map { :'network_storage_id' => :'networkStorageId', :'network_storage_name' => :'networkStorageName', :'volume_id' => :'volumeId', :'volume_name' => :'volumeName', :'capacity_in_gb' => :'capacityInGb', :'created_on' => :'createdOn' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 178 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 60 def self.openapi_types { :'network_storage_id' => :'String', :'network_storage_name' => :'String', :'volume_id' => :'String', :'volume_name' => :'String', :'capacity_in_gb' => :'Integer', :'created_on' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
152 153 154 155 156 157 158 159 160 161 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 152 def ==(o) return true if self.equal?(o) self.class == o.class && network_storage_id == o.network_storage_id && network_storage_name == o.network_storage_name && volume_id == o.volume_id && volume_name == o.volume_name && capacity_in_gb == o.capacity_in_gb && created_on == o.created_on end |
#eql?(o) ⇒ Boolean
165 166 167 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 165 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
171 172 173 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 171 def hash [network_storage_id, network_storage_name, volume_id, volume_name, capacity_in_gb, created_on].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
122 123 124 125 126 127 128 129 130 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 122 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @capacity_in_gb.nil? invalid_properties.push('invalid value for "capacity_in_gb", capacity_in_gb cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
134 135 136 137 138 |
# File 'lib/pnap_billing_api/models/storage_details.rb', line 134 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @capacity_in_gb.nil? true end |