Class: BillingApi::SystemCreditDetails

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_billing_api/models/system_credit_details.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SystemCreditDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `BillingApi::SystemCreditDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `BillingApi::SystemCreditDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'applied_amount')
    self.applied_amount = attributes[:'applied_amount']
  else
    self.applied_amount = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'cause')
    self.cause = attributes[:'cause']
  else
    self.cause = nil
  end
end

Instance Attribute Details

#applied_amountObject

Amount applied.



19
20
21
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 19

def applied_amount
  @applied_amount
end

#causeObject

Returns the value of attribute cause.



23
24
25
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 23

def cause
  @cause
end

#typeObject

Returns the value of attribute type.



21
22
23
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 21

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 48

def self.attribute_map
  {
    :'applied_amount' => :'appliedAmount',
    :'type' => :'type',
    :'cause' => :'cause'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 208

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



82
83
84
85
86
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 82

def self.openapi_all_of
  [
  :'CreditDetailsBase'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 67

def self.openapi_types
  {
    :'applied_amount' => :'Float',
    :'type' => :'CreditTypeEnum',
    :'cause' => :'SystemCreditCauseEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



185
186
187
188
189
190
191
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 185

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      applied_amount == o.applied_amount &&
      type == o.type &&
      cause == o.cause
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



201
202
203
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 201

def hash
  [applied_amount, type, cause].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 125

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @applied_amount.nil?
    invalid_properties.push('invalid value for "applied_amount", applied_amount cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @cause.nil?
    invalid_properties.push('invalid value for "cause", cause cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
149
150
151
# File 'lib/pnap_billing_api/models/system_credit_details.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @applied_amount.nil?
  return false if @type.nil?
  return false if @cause.nil?
  true
end